# Python Helpers

This repository is a pyhton PIP module to ease daily coding.

## Versioning

The [Semantic versioning](https://semver.org) is used for this package.

## `buildconfig.json`

This JSON file holds the last built version of the Python package. If the minor version number is changed, the patch version has to be set to `-1` manually, so the next build by GitHub workflow will result in patch version `x.y.0`.

## Documentation

The [documentation of this project](https://macwinnie.github.io/python-helpers) is published as GitHub page.

## License

This project is published unter [AGPL-3.0-or-later](LICENSE) license.

## Contributing

Please read [CONTRIBUTING.md](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.
